@@ -258,6 +258,8 @@ class FileAPI(API):
         is_temporary: bool = False,
         inline_offset: Optional[int] = None,
         xline_offset: Optional[int] = None,
+        cdp_x_offset: Optional[int] = None,
+        cdp_y_offset: Optional[int] = None,
     ):
         """Register a file on a survey
 
@@ -269,6 +271,10 @@ class FileAPI(API):
             crs (str): The CRS of the file
             metadata (dict, optional): A string -> string dictionary with any metadata to add about the file
             is_temporary: is the file temporary - ie generated on the fly instead of being ingested from the bucket
+            inline_offset: Byte offset of inline number field in the trace headers. Defaults to 189 as per the SEG-Y rev1 specification
+            xline_offset: Byte offset of crossline number field in the trace headers. Defaults to 193 as per the SEG-Y rev1 specification
+            cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers. Defaults to 181 as per the SEG-Y rev1 specification
+            cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers. Defaults to 185 as per the SEG-Y rev1 specification
 
         Returns:
              The response from the gRPC server with the id the file was registered on.
@@ -276,6 +282,8 @@ class FileAPI(API):
         survey = self.identify(survey_id, survey_name)
         inline_offset_wrapped = None if inline_offset == None else wrappers.Int32Value(value=inline_offset)
         xline_offset_wrapped = None if xline_offset == None else wrappers.Int32Value(value=xline_offset)
+        cdp_x_offset_wrapped = None if cdp_x_offset == None else wrappers.Int32Value(value=cdp_x_offset)
+        cdp_y_offset_wrapped = None if cdp_y_offset == None else wrappers.Int32Value(value=cdp_y_offset)
         request = RegisterFileRequest(
             survey=survey,
             path=bucket,
@@ -285,6 +293,8 @@ class FileAPI(API):
             is_temporary=wrappers.BoolValue(value=is_temporary),
             inline_offset=inline_offset_wrapped,
             crossline_offset=xline_offset_wrapped,
+            cdp_x_offset=cdp_x_offset_wrapped,
+            cdp_y_offset=cdp_y_offset_wrapped,
         )
         return self.ingestion.RegisterFile(request, metadata=self.metadata)
 
@@ -351,6 +361,8 @@ class FileAPI(API):
         crs: str = None,
         inline_offset: Optional[int] = None,
         xline_offset: Optional[int] = None,
+        cdp_x_offset: Optional[int] = None,
+        cdp_y_offset: Optional[int] = None,
     ):
         """Edit a file by either its id or name.
 
@@ -361,6 +373,10 @@ class FileAPI(API):
             new_name (str): New name of the file.
             metadata (dict): New metadata of the file.
             crs (str): New CRS of the file.
+            inline_offset: Byte offset of inline number field in the trace headers.
+            xline_offset: Byte offset of crossline number field in the trace headers.
+            cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers.
+            cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers.
 
         Returns:
             EditFileResponse: File information including file id, name, path and crs.
@@ -368,6 +384,8 @@ class FileAPI(API):
         file = self.identify(file_id, file_name)
         inline_offset_wrapped = None if inline_offset == None else wrappers.Int32Value(value=inline_offset)
         xline_offset_wrapped = None if xline_offset == None else wrappers.Int32Value(value=xline_offset)
+        cdp_x_offset_wrapped = None if cdp_x_offset == None else wrappers.Int32Value(value=cdp_x_offset)
+        cdp_y_offset_wrapped = None if cdp_y_offset == None else wrappers.Int32Value(value=cdp_y_offset)
         crs_wrapped = None if crs == None else CRS(crs=crs)
         request = EditFileRequest(
             file=file,
@@ -377,6 +395,8 @@ class FileAPI(API):
             crs=crs_wrapped,
             inline_offset=inline_offset_wrapped,
             crossline_offset=xline_offset_wrapped,
+            cdp_x_offset=cdp_x_offset_wrapped,
+            cdp_y_offset=cdp_y_offset_wrapped,
         )
         return self.ingestion.EditFile(request=request, metadata=self.metadata)
 
