@@ -8,11 +8,6 @@ from cognite.seismic._api.api import API
 from cognite.seismic._api.utility import Direction, LineRange, MaybeString, get_identifier, get_search_spec
 from cognite.seismic.data_classes.api_types import RangeInclusive, Trace, VolumeDef
 
-try:
-    from tqdm.auto import tqdm
-except ImportError:
-    tqdm = None
-
 if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.types_pb2 import GeoJson
     from cognite.seismic.protos.types_pb2 import Geometry as GeometryProto
@@ -62,6 +57,21 @@ class ArrayData(NamedTuple):
         )
 
 
+class GetVolumeSize(NamedTuple):
+    """Information about the size returned from get_volume.
+
+    Attributes:
+        trace_count: The number of traces that will be streamed
+        sample_count: The number of samples in each trace, if available
+        size_kilobytes: An estimate of the total streaming size in kilobytes (= 1024 bytes), 
+                        or None if sample_count is None
+        """
+
+    trace_count: int
+    sample_count: Optional[int]
+    size_kilobytes: Optional[int]
+
+
 class VolumeSeismicAPI(API):
     def __init__(self, query, ingestion, metadata):
         super().__init__(query=query, ingestion=ingestion, metadata=metadata)
@@ -89,11 +99,11 @@ class VolumeSeismicAPI(API):
             seismic_store_id (int | None): The id of the seismic store to query
             inline_range ([int, int] | [int, int, int] | None): The inline range
             xline_range ([int, int] | [int, int, int] | None): The xline range
-            z_range ([int, int] | [int, int, int]): The zline range
+            z_range ([int, int] | [int, int, int]): The range of samples to include
             include_trace-header (bool): Whether to include trace header info in the response.
 
         Returns:
-            Iterable[:py:class:`~cognite.seismic.data_classes.api_types.Trace`]: The traces for the specified volume
+            Iterable[:py:class:`~cognite.seismic.data_classes.api_types.Trace`], the traces for the specified volume
         """
         inline = into_line_range(inline_range)
         xline = into_line_range(xline_range)
@@ -108,6 +118,77 @@ class VolumeSeismicAPI(API):
         for proto in self.query.GetVolume(req, metadata=self.metadata):
             yield Trace.from_proto(proto)
 
+    def _get_volumedef(
+        self, *, id: Optional[int] = None, external_id: MaybeString = None, seismic_store_id: Optional[int] = None
+    ) -> VolumeDef:
+        """Helper function for get_volume_size and get_array to fetch the volumedef"""
+        if seismic_store_id:
+            spec = get_search_spec(id=seismic_store_id)
+            req = SearchSeismicStoresRequest(seismic_store=spec)
+            req.include_volume_definitions = True
+            [store] = self.query.SearchSeismicStores(req, metadata=self.metadata)
+            return VolumeDef.from_proto(store.inline_volume_def)
+        else:
+            spec = get_search_spec(id, external_id)
+            req = SearchSeismicsRequest(seismic=spec)
+            req.include_volume_definition = True
+            [seismic] = self.query.SearchSeismics(req, metadata=self.metadata)
+            return VolumeDef.from_proto(seismic.volume_def)
+
+    def get_volume_size(
+        self,
+        *,
+        id: Optional[int] = None,
+        external_id: MaybeString = None,
+        seismic_store_id: Optional[int] = None,
+        inline_range: Optional[LineRange] = None,
+        xline_range: Optional[LineRange] = None,
+        z_range: Optional[LineRange] = None,
+        include_trace_header: bool = False,
+    ) -> GetVolumeSize:
+        """Estimate the total size of data streamed by get_volume
+
+        Parameters: See :py:meth:`VolumeSeismicAPI.get_volume`
+
+        Returns:
+            A :py:class:`~GetVolumeSize` object describing the size
+        """
+        volumedef = self._get_volumedef(id=id, external_id=external_id, seismic_store_id=seismic_store_id)
+        # Ignore step sizes
+        if inline_range is not None:
+            inline_range = inline_range[:2]
+        if xline_range is not None:
+            xline_range = xline_range[:2]
+        trace_count = volumedef.count_total_traces(inline_range=inline_range, xline_range=xline_range)
+        sample_count = volumedef.parsed.get("sample_count")
+        if sample_count is not None:
+            if z_range is not None:
+                (z_min, z_max) = z_range[0:2]
+                if z_max < z_min:
+                    raise (Exception("z_range has min > max"))
+                # Clip max to sample_count
+                if z_max > sample_count:
+                    z_max = sample_count
+                # Max may have become smaller than min after clipping
+                if z_max < z_min:
+                    z_min = z_max
+                sample_count = z_max - z_min + 1
+
+            # According to segy spec
+            header_size = 240 if include_trace_header else 0
+            int32_size = 4
+            float_size = 4
+            # I guess we will have to do with this estimate?
+            crs_size = len(b"EPSG:23031") + 1  # Null-terminated?
+            coordinate_size = crs_size + 2 * float_size
+            trace_size = header_size + 2 * int32_size + float_size * sample_count + coordinate_size
+            size_bytes = trace_count * trace_size
+            size_kilobytes = round(size_bytes / 1024)
+        else:
+            size_kilobytes = None
+
+        return GetVolumeSize(trace_count=trace_count, sample_count=sample_count, size_kilobytes=size_kilobytes)
+
     # Refuse to allocate arrays larger than this
     # FIXME(audunska): Figure out the right limit here, or maybe just use numpy's memory limit
     ARR_LIM = 1e8
@@ -135,35 +216,15 @@ class VolumeSeismicAPI(API):
             seismic_store_id (int | None): The id of the seismic store to query
             inline_range ([int, int] | [int, int, int] | None): The inline range
             xline_range ([int, int] | [int, int, int] | None): The xline range
-            z_range ([int, int] | [int, int, int]): The zline range
+            z_range ([int, int] | [int, int, int]): The range of samples to include
             progress: (bool): If set to true, display a progress bar. Default: False
 
         Returns:
             An :py:class:`~ArrayData` object encapsulating the retrieved array (see below)
         """
 
-        z_size = None
-        # Fetch the corresponding VolumeDef
-        if seismic_store_id:
-            spec = get_search_spec(id=seismic_store_id)
-            req = SearchSeismicStoresRequest(seismic_store=spec)
-            req.include_volume_definitions = True
-            req.include_headers = True
-            [store] = self.query.SearchSeismicStores(req, metadata=self.metadata)
-            volumedef = VolumeDef.from_proto(store.inline_volume_def)
-            z_size = volumedef.parsed.get("sample_count")
-            if z_size is None and store.binary_header is not None:
-                z_size = store.binary_header.samples
-        else:
-            spec = get_search_spec(id, external_id)
-            req = SearchSeismicsRequest(seismic=spec)
-            req.include_volume_definition = True
-            req.include_binary_header = True
-            [seismic] = self.query.SearchSeismics(req, metadata=self.metadata)
-            volumedef = VolumeDef.from_proto(seismic.volume_def)
-            z_size = volumedef.parsed.get("sample_count")
-            if z_size is None and seismic.binary_header is not None:
-                z_size = seismic.binary_header.samples
+        volumedef = self._get_volumedef(id=id, external_id=external_id, seismic_store_id=seismic_store_id)
+        z_size = volumedef.parsed.get("sample_count")
 
         # Compute optimal ranges
         if inline_range is None:
@@ -208,9 +269,10 @@ class VolumeSeismicAPI(API):
             include_trace_header=False,
         )
         if progress:
-            if tqdm is None:
+            try:
+                from tqdm.auto import tqdm
+            except ImportError:
                 raise Exception("progress=True requires the tqdm package. Install with 'pip install tqdm'.")
-            # Due to SBS-3251, the number of traces streamed is > inline_size*xline_size:
             traces = tqdm(
                 traces,
                 total=volumedef.count_total_traces(
